/* Test Darwin linker option -bundle.  */
/* Developed by Devang Patel <dpatel@apple.com>.  */

/* { dg-options "-bundle" } */
/* { dg-do link { target powerpc-*-darwin* } } */

int main()
{
  return 0;
}

