/* Test the tester.  */
/* { dg-prms-id 42 } */
/* { dg-options "-Wall" } */

/* FIXME: we want to test dg-lose here.  Anyone know of a good way to
   crash the compiler?  */

int
main (int argc, char *argv[])
{
  return 0;
}
